@@ -7,13 +7,25 @@ use strict;
 
 use Crypt::Blowfish_PP;
 use FlashVideo::Utils;
+use FlashVideo::JSON;
 use MIME::Base64;
+use Time::HiRes qw(time);
 
 use constant TOKEN_DECRYPT_KEY => 'STINGMIMI';
 
+our $VERSION = '0.04';
+sub Version() { $VERSION;}
+
 sub find_video {
   my ($self, $browser, $embed_url, $prefs) = @_;
 
+
+  if ($browser->response->is_redirect) {
+    my $relurl = $browser->response->header('Location');
+    info "Relocated to $relurl";
+    $browser->get($relurl);
+  }
+
   my $page_url = $browser->uri->as_string;
 
   # Determine series and episode. Channel 4 sometimes have these backwards,
@@ -25,6 +37,9 @@ sub find_video {
     $series_and_episode = sprintf "S%02dE%02d", $1, $2;
   }
 
+  # Create a uid
+  my $uid = int(time*1000);
+
   # get SWF player file
   my $swf_player;
   if ($browser->content =~ /fourodPlayerFile\s+=\s+\'(4od\S+\.swf)\'/i) {
@@ -55,11 +70,97 @@ sub find_video {
     die "Couldn't get asset XML: " . $browser->response->status_line;
   }
 
-  my $xml = from_xml($raw_xml);
+  my $xml_ref = from_xml($raw_xml);
+  my $xml;
 
-  my $stream_url = $xml->{assetInfo}->{uriData}->{streamUri};
-  my $token      = $xml->{assetInfo}->{uriData}->{token};
-  my $cdn        = $xml->{assetInfo}->{uriData}->{cdn};
+
+  # Check for mp4 if not then try different assetId
+  my $lower_id = 0;
+  my $upper_id = 9999999;
+  if ($xml_ref->{assetInfo}->{uriData}->{streamUri} !~ /mp4$/ ) {
+    
+    my $find_url = "http://ps3.channel4.com/pmlsd/" . 
+        $xml_ref->{assetInfo}->{webSafeBrandTitle} .
+        "/4od.json?platform=ps3&uid=" . $uid;
+
+    $browser->get($find_url);
+    if ($browser->success) {
+      my $json = from_json($browser->content);
+
+      my $fstr = sprintf "%s/%03d", $xml_ref->{assetInfo}->{contractId}, 
+                   $xml_ref->{assetInfo}->{programmeNumber};
+      info "Looking for programmeId $fstr";
+      my @entries;
+      if (ref($json->{feed}->{entry}) eq "ARRAY") {
+        @entries = @{$json->{feed}->{entry}};
+      }
+      else
+      {
+        $entries[0] = $json->{feed}->{entry};
+      }
+      foreach my $entry ( @entries ) {
+        if ($entry->{'dc:relation.programmeId'} eq $fstr) {
+          my $ps3_url = $entry->{group}->{player}->{'@url'};
+          info $entry->{'dc:relation.BrandTitle'} .
+            ' - ' . $entry->{title} .
+            ' Series ' . $entry->{'dc:relation.SeriesNumber'} .
+            ' Episode ' . $entry->{'dc:relation.EpisodeNumber'} .
+            ' ProgrammeId ' . $entry->{'dc:relation.programmeId'} .
+            ' Url ' . $ps3_url;
+          $raw_xml = $browser->get($ps3_url);
+          if ($browser->success) {
+            my $xml_off = from_xml($raw_xml);
+            if ($xml_off->{assetInfo}->{uriData}->{streamUri} =~ /mp4$/ ) {
+              $xml = $xml_off;
+              info "Found mp4 stream url $ps3_url siteSectionId $xml->{assetInfo}->{adverts}->{siteSectionId}";
+            }
+          }
+        }
+      }
+
+    }
+    if  (! defined($xml)) {
+      for (my $off = 2; $off < 20; $off++) {
+        my $asset_off = $off >> 1;
+        $asset_off = -$asset_off if ($off & 1);
+        $asset_off += $asset_id; 
+        if ($asset_off > $lower_id && $asset_off < $upper_id) {
+          $raw_xml = $browser->get("http://ais.channel4.com/asset/$asset_off");
+          if ($browser->success) {
+            my $xml_off = from_xml($raw_xml); 
+            # Check Same programme
+            if ( $xml_off->{assetInfo}->{brandTitle}      eq  $xml_ref->{assetInfo}->{brandTitle} &&
+                 $xml_off->{assetInfo}->{programmeNumber} eq  $xml_ref->{assetInfo}->{programmeNumber}) {
+              if ($xml_off->{assetInfo}->{uriData}->{streamUri} =~ /mp4$/ ) {
+                $xml = $xml_off;
+                info "Found mp4 stream asset id $asset_off siteSectionId $xml->{assetInfo}->{adverts}->{siteSectionId}";
+                if ($xml->{assetInfo}->{uriData}->{streamUri} =~ /\.ps3-/ ) {
+                   last;
+                }
+              }
+            }
+            else {
+              if ($asset_off > $asset_id ) {
+                $upper_id = $asset_off;
+              }
+              else {
+                $lower_id = $asset_off;
+              }
+            }
+          } 
+        }
+      }
+    }
+  }
+  else {
+    $xml = $xml_ref;
+  }
+
+  die "Unable to find suitable stream - may not be available yet\n" unless defined $xml;
+
+  my $stream_url  = $xml->{assetInfo}->{uriData}->{streamUri};
+  my $token       = $xml->{assetInfo}->{uriData}->{token};
+  my $cdn         = $xml->{assetInfo}->{uriData}->{cdn};
 
   my $decoded_token = decode_4od_token($token);
 
@@ -102,7 +203,7 @@ sub find_video {
     $title = join " - ", @title_components;
   }
   
-  my $filename = title_to_filename($title, "mp4");
+  my $filename = title_to_filename($title, "flv");
 
   # Get subtitles if necessary.
   if ($prefs->subtitles) {
